@@ -177,6 +177,7 @@ combine_mtables <- function(...){
     digits <- attr(args[[1]],"digits")
     stemplates <- do.call(c,lapply(args,attr,"stemplates"))
     sdigits <- attr(args[[1]],"sdigits")
+    show.eqnames <- attr(args[[1]],"show.eqnames")
 
     args <- lapply(args,unclass)
 
@@ -195,6 +196,7 @@ combine_mtables <- function(...){
             digits=digits,
             stemplates=stemplates,
             sdigits=sdigits,
+            show.eqnames=show.eqnames,
             model.groups=model.groups
             )
 }
